@@ -1,13 +1,14 @@
 use poem::{handler, http::StatusCode, route, web::Path, EndpointExt, Response, Server};
 
-#[handler(method = "get")]
+#[handler]
 fn hello(Path(name): Path<String>) -> String {
     format!("hello: {}", name)
 }
 
 #[tokio::main]
 async fn main() {
-    let app = route().at("/hello/:name", hello).after(|resp| async move {
+    let mut app = route();
+    app.at("/hello/:name").get(hello.after(|resp| async move {
         if resp.status() == StatusCode::NOT_FOUND {
             Response::builder()
                 .status(StatusCode::NOT_FOUND)
@@ -15,7 +16,7 @@ async fn main() {
         } else {
             resp
         }
-    });
+    }));
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
 }
