@@ -1,13 +1,14 @@
 use poem::{handler, route, web::Path, Server};
 
-#[handler(method = "get")]
+#[handler]
 fn hello(Path(name): Path<String>) -> String {
     format!("hello: {}", name)
 }
 
 #[tokio::main]
 async fn main() {
-    let app = route().at("/hello/:name", hello);
+    let mut app = route();
+    app.at("/hello/:name").get(hello);
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
 }
