@@ -1,6 +1,6 @@
 use std::future::Future;
 
-use crate::{Endpoint, IntoResponse, Request, Response};
+use crate::{Endpoint, IntoResponse, Request};
 
 /// Endpoint for the [`after`](super::EndpointExt::after) method.
 pub struct After<E, F> {
@@ -19,11 +19,13 @@ impl<E, F> After<E, F> {
 impl<E, F, Fut, R> Endpoint for After<E, F>
 where
     E: Endpoint,
-    F: Fn(Response) -> Fut + Send + Sync + 'static,
+    F: Fn(E::Output) -> Fut + Send + Sync + 'static,
     Fut: Future<Output = R> + Send + 'static,
     R: IntoResponse,
 {
-    async fn call(&self, req: Request) -> Response {
-        (self.f)(self.inner.call(req).await).await.into_response()
+    type Output = R;
+
+    async fn call(&self, req: Request) -> Self::Output {
+        (self.f)(self.inner.call(req).await).await
     }
 }
