@@ -1,6 +1,6 @@
 use std::future::Future;
 
-use crate::{Endpoint, Error, Request, Response, Result};
+use crate::{Endpoint, Error, IntoResponse, Request, Result};
 
 /// Endpoint for the [`map_err`](super::EndpointExt::map_err) method.
 pub struct MapErr<E, F> {
@@ -16,13 +16,16 @@ impl<E, F> MapErr<E, F> {
 }
 
 #[async_trait::async_trait]
-impl<E, F, Fut> Endpoint for MapErr<E, F>
+impl<E, F, Fut, R> Endpoint for MapErr<E, F>
 where
-    E: Endpoint,
+    E: Endpoint<Output = Result<R>>,
     F: Fn(Error) -> Fut + Send + Sync + 'static,
     Fut: Future<Output = Error> + Send + 'static,
+    R: IntoResponse,
 {
-    async fn call(&self, req: Request) -> Result<Response> {
+    type Output = E::Output;
+
+    async fn call(&self, req: Request) -> Self::Output {
         match self.inner.call(req).await {
             Ok(resp) => Ok(resp),
             Err(err) => Err((self.f)(err).await),
