@@ -1,6 +1,6 @@
 use std::future::Future;
 
-use crate::{Endpoint, IntoResponse, Request, Response, Result};
+use crate::{Endpoint, IntoResponse, Request, Result};
 
 /// Endpoint for the [`map_ok`](super::EndpointExt::map_ok) method.
 pub struct MapOk<E, F> {
@@ -16,16 +16,19 @@ impl<E, F> MapOk<E, F> {
 }
 
 #[async_trait::async_trait]
-impl<E, F, Fut, R> Endpoint for MapOk<E, F>
+impl<E, F, Fut, R, R2> Endpoint for MapOk<E, F>
 where
-    E: Endpoint,
-    F: Fn(Response) -> Fut + Send + Sync + 'static,
-    Fut: Future<Output = R> + Send + 'static,
+    E: Endpoint<Output = Result<R>>,
+    F: Fn(R) -> Fut + Send + Sync + 'static,
+    Fut: Future<Output = R2> + Send + 'static,
     R: IntoResponse,
+    R2: IntoResponse,
 {
-    async fn call(&self, req: Request) -> Result<Response> {
+    type Output = Result<R2>;
+
+    async fn call(&self, req: Request) -> Self::Output {
         match self.inner.call(req).await {
-            Ok(resp) => (self.f)(resp).await.into_response(),
+            Ok(resp) => Ok((self.f)(resp).await),
             Err(err) => Err(err),
         }
     }
