@@ -1,4 +1,4 @@
-use crate::{Endpoint, Request, Response, Result};
+use crate::{Endpoint, IntoResponse, Request, Response};
 
 /// Endpoint for the [`map_to_response`](super::EndpointExt::map_to_response)
 /// method.
@@ -14,14 +14,10 @@ impl<E> MapToResponse<E> {
 }
 
 #[async_trait::async_trait]
-impl<E> Endpoint for MapToResponse<E>
-where
-    E: Endpoint,
-{
-    async fn call(&self, req: Request) -> Result<Response> {
-        match self.inner.call(req).await {
-            Ok(resp) => Ok(resp),
-            Err(err) => Ok(err.as_response()),
-        }
+impl<E: Endpoint> Endpoint for MapToResponse<E> {
+    type Output = Response;
+
+    async fn call(&self, req: Request) -> Self::Output {
+        self.inner.call(req).await.into_response()
     }
 }
