@@ -5,20 +5,16 @@ mod and_then;
 mod before;
 #[allow(clippy::module_inception)]
 mod endpoint;
-mod guard_endpoint;
 mod map_err;
 mod map_ok;
 mod map_to_response;
 mod map_to_result;
-mod or;
 
 pub use after::After;
 pub use and_then::AndThen;
 pub use before::Before;
 pub use endpoint::{fn_endpoint, Endpoint, EndpointExt};
-pub use guard_endpoint::GuardEndpoint;
 pub use map_err::MapErr;
 pub use map_ok::MapOk;
 pub use map_to_response::MapToResponse;
 pub use map_to_result::MapToResult;
-pub use or::Or;
