@@ -45,7 +45,7 @@ impl<E: Endpoint> Endpoint for TracingImpl<E> {
         async move {
             let resp = fut.await.into_response();
 
-            if resp.status().is_success() {
+            if resp.is_success() {
                 ::tracing::info!(status = %resp.status(), "send response");
             } else {
                 ::tracing::error!(status = %resp.status(), "an error occurred");
