@@ -34,7 +34,10 @@ pub mod type_headers {
     };
 }
 
-use std::convert::{Infallible, TryInto};
+use std::{
+    convert::{Infallible, TryInto},
+    net::{IpAddr, SocketAddr},
+};
 
 use bytes::Bytes;
 #[cfg(feature = "compression")]
@@ -96,6 +99,14 @@ impl RequestBody {
 ///
 ///    Extracts the [`Request`] from the incoming request.
 ///
+/// - **SocketAddr**
+///
+///    Extracts the remote address [`SocketAddr`] from request.
+///
+/// - **IpAddr**
+///
+///    Extracts the remote ip address [`SocketAddr`] from request.
+///
 /// - **Method**
 ///
 ///    Extracts the [`Method`] from the incoming request.
@@ -624,9 +635,30 @@ impl<'a> FromRequest<'a> for Vec<u8> {
     }
 }
 
+#[async_trait::async_trait]
+impl<'a> FromRequest<'a> for SocketAddr {
+    async fn from_request(req: &'a Request, _body: &mut RequestBody) -> Result<Self> {
+        Ok(req.state().remote_addr)
+    }
+}
+
+#[async_trait::async_trait]
+impl<'a> FromRequest<'a> for IpAddr {
+    async fn from_request(req: &'a Request, _body: &mut RequestBody) -> Result<Self> {
+        Ok(req.state().remote_addr.ip())
+    }
+}
+
 #[async_trait::async_trait]
 impl<'a, T: FromRequest<'a>> FromRequest<'a> for Option<T> {
     async fn from_request(req: &'a Request, body: &mut RequestBody) -> Result<Self> {
         Ok(T::from_request(req, body).await.ok())
     }
 }
+
+#[async_trait::async_trait]
+impl<'a, T: FromRequest<'a>> FromRequest<'a> for Result<T> {
+    async fn from_request(req: &'a Request, body: &mut RequestBody) -> Result<Self> {
+        Ok(T::from_request(req, body).await)
+    }
+}
